# mantra-py

A Python library to interact with the Mantra chain

Documentation can be found [here](https://quantum-architects.github.io/mantrapy)

## Build docs locally

```sh
npm install
npm run dev
```
